/**
 * @file bootloader.c
 *
 * @brief This file contains bootloader routines for the I2C-MP-USB firmware
 *        project.
 *
 * @author Thomas Fischl
 * @copyright (c) 2017-2019 Thomas Fischl
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 */


#include "clock.h"
#include "usb.h"
#include "bootloader.h"

#define BOOTLOADER_STATE_OFF 0
#define BOOTLOADER_STATE_TRIGGERED 1
#define BOOTLOADER_STATE_SHUTDOWNAPP 2

unsigned char bootloader_state = BOOTLOADER_STATE_OFF;
unsigned char bootloader_timestamp;

/**
 * @brief Trigger start of bootloader
 */
void bootloader_triggerStart() {
    bootloader_state = BOOTLOADER_STATE_TRIGGERED;
    bootloader_timestamp = clock_tickerSlow;
    
}

/**
 * @brief Handle periodic task. Check if bootloader start was triggered, then
 * initiate shutdown and jump to bootloader.
 */
void bootloader_process() {
    
    switch (bootloader_state) {
        
        case BOOTLOADER_STATE_OFF:
            return;
            
        case BOOTLOADER_STATE_TRIGGERED:
            if (clock_diff(bootloader_timestamp) > 25) {
                bootloader_state = BOOTLOADER_STATE_SHUTDOWNAPP;
                bootloader_timestamp = clock_tickerSlow;
                
                usb_shutdown();
            }
            break;
            
        case BOOTLOADER_STATE_SHUTDOWNAPP:
            if (clock_diff(bootloader_timestamp) > 25) {
                
                // jump to bootloader
                asm ("MOVLP 0x00");
                asm ("GOTO 0x30");                
            }
            break;
    }        
    
}
