/**
 * @file led.c
 *
 * @brief This file contains led routines for the I2C-MP-USB
 *        firmware project.
 *
 * @author Thomas Fischl
 * @copyright (c) 2017-2019 Thomas Fischl
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */

#include <xc.h>
#include "clock.h"
#include "led.h"

unsigned char state_laststamp;
unsigned char periodticker;

/**
 * @brief Initialize LED handling
 */
void led_init() {
    periodticker = 0;
    LED_PIN = 1;
}

/**
 * @brief Flash LED
 */
void led_flash() {
    
    // check if already flashing
    if (periodticker) return;
    
    periodticker = LED_FLASHPERIOD;
    LED_PIN = 0;
}

/**
 * @brief Timer interrupt routine 100 Hz
 */
inline void led_isr() {

    if (!periodticker) return;
    
    if (periodticker == LED_FLASHTIMEOFF) LED_PIN = 1;
    
    periodticker--;
    
}
