/**
 * @file usb_descr.h
 *
 * @brief This file contains the USB descriptor defines for the I2C-MP-USB
 *        firmware project. The descriptor is based on the I2C-Tiny-USB defines
 *        by Till Harbaum (https://github.com/harbaum/I2C-Tiny-USB) and uses the
 *        same VID/PID to be compatible with i2c-tiny-usb applications.
 *
 * @author Thomas Fischl
 * @copyright (c) 2017-2019 Thomas Fischl
 * 
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */
#ifndef _USB_DESCR_
#define _USB_DESCR_

#define DESCR_DEVICE 0x01
#define DESCR_CONFIG 0x02
#define DESCR_STRING 0x03
#define DESCR_INTERFACE 0x04
#define DESCR_ENDPOINT 0x05
#define DESCR_HID 0x21
#define DESCR_HID_REPORT 0x22

const unsigned char usb_dev_desc[] = {
    18,
    0x01,
    0x00, 0x02,
    0x02, // Class code
    0x00,
    0x00,
    0x08, // max packet size
    0x03, 0x04, // vendor   (use i2c-tiny-usb VID/PID pair donated by FTDI)
    0x31, 0xc6, // product
    0x01, 0x01, // device release
    0x01, // manuf string
    0x02, // product string
    0x00, // serial number string (if number available, index 3 is set on the fly)
    0x01
};

const unsigned char usb_config_desc[] = {
    0x09, /* bLength: Configuation Descriptor size */
    0x02, /* bDescriptorType: Configuration */
    9 + 9, /* wTotalLength:no of returned bytes */
    0x00,
    0x01, /* bNumInterfaces: 1 interface */
    0x01, /* bConfigurationValue: Configuration value */
    0x00, /* iConfiguration: Index of string descriptor describing the configuration */
    0x80, /* bmAttributes: bus powered */
    50, /* MaxPower 100 mA */
    /*Interface Descriptor*/
    0x09, /* bLength: Interface Descriptor size */
    0x04, /* bDescriptorType: Interface */
    /* Interface descriptor type */
    0x00, /* bInterfaceNumber: Number of Interface */
    0x00, /* bAlternateSetting: Alternate setting */
    0x00, /* bNumEndpoints */
    0x00, /* bInterfaceClass*/
    0x00, /* bInterfaceSubClass */
    0x00, /* bInterfaceProtocol */
    0x00, /* iInterface: */
};

const unsigned char usb_string_language[] = {4, 0x03, 0x09, 0x04};

#ifdef USE_I2C_TINY_USB_STRINGS
const unsigned char usb_string_product[] = {26, 0x03, 'i', 0x00, '2', 0x00, 'c', 0x00, '-', 0x00, 't', 0x00, 'i', 0x00, 'n', 0x00, 'y', 0x00, '-', 0x00, 'u', 0x00, 's', 0x00, 'b', 0x00};
const unsigned char usb_string_manuf[] = {26, 0x03, 'T', 0x00, 'i', 0x00, 'l', 0x00, 'l', 0x00, ' ', 0x00, 'H', 0x00, 'a', 0x00, 'r', 0x00, 'b', 0x00, 'a', 0x00, 'u', 0x00, 'm', 0x00};
#else
const unsigned char usb_string_product[] = {22, 0x03, 'I', 0x00, '2', 0x00, 'C', 0x00, '-', 0x00, 'M', 0x00, 'P', 0x00, '-', 0x00, 'U', 0x00, 'S', 0x00, 'B', 0x00};
const unsigned char usb_string_manuf[] = {28, 0x03, 'w', 0x00, 'w', 0x00, 'w', 0x00, '.', 0x00, 'f', 0x00, 'i', 0x00, 's', 0x00, 'c', 0x00, 'h', 0x00, 'l', 0x00, '.', 0x00, 'd', 0x00, 'e', 0x00};
#endif

#endif